==> 0.0.25.tar.gz: lib/receipt/receipt_text.dart <==
import 'package:rw_blue_print_pos/receipt/receipt_column.dart';

import 'collection_style.dart';
import 'receipt_alignment.dart';
import 'receipt_text_size_type.dart';
import 'receipt_text_style.dart';
import 'receipt_text_style_type.dart';

class ReceiptText {
  ReceiptText(
    this.text, {
    this.textStyle = const ReceiptTextStyle(
      type: ReceiptTextStyleType.normal,
      size: ReceiptTextSizeType.medium,
    ),
    this.alignment = ReceiptAlignment.center,
    this.column = ReceiptColumn.one,
    this.isMargin = false
  });

  final String text;
  final ReceiptTextStyle textStyle;
  final ReceiptAlignment alignment;
  final ReceiptColumn column;
  final bool isMargin;

  String get html => '''
    <div class="$_column $_columnMargin $_alignmentStyleHTML ${textStyle.textSizeHtml}">
      <${textStyle.textStyleHTML}>$text</${textStyle.textStyleHTML}>
    </div>
    ''';

  String get _alignmentStyleHTML {
    if (alignment == ReceiptAlignment.left) {
      return CollectionStyle.textLeft;
    } else if (alignment == ReceiptAlignment.right) {
      return CollectionStyle.textRight;
    }
    return CollectionStyle.textCenter;
  }

  String get _column {
    if (column == ReceiptColumn.two) {
      return CollectionStyle.columnTwo;
    } else if (column == ReceiptColumn.three) {
      return CollectionStyle.columnThree;
    }
    return CollectionStyle.columnOne;
  }
  String get _columnMargin {
    if(isMargin)
      return CollectionStyle.columnTwoMargin;
    return '';
  }
}

==> 0.0.34.tar.gz: lib/receipt/receipt_text.dart <==
import 'package:rw_blue_print_pos/receipt/receipt_column.dart';

import 'collection_style.dart';
import 'receipt_alignment.dart';
import 'receipt_text_size_type.dart';
import 'receipt_text_style.dart';
import 'receipt_text_style_type.dart';

class ReceiptText {
  ReceiptText(
    this.text, {
    this.textStyle = const ReceiptTextStyle(
      type: ReceiptTextStyleType.normal,
      size: ReceiptTextSizeType.medium,
    ),
    this.alignment = ReceiptAlignment.center,
    this.column = ReceiptColumn.one,
    this.isMargin = false,
    this.symbol = ''
  });

  final String text;
  final ReceiptTextStyle textStyle;
  final ReceiptAlignment alignment;
  final ReceiptColumn column;
  final bool isMargin;
  final String symbol;

  String get html => '''
    <div class="$_column $_columnMargin $_alignmentStyleHTML ${textStyle.textSizeHtml}">
      $_symbol <${textStyle.textStyleHTML}>$text</${textStyle.textStyleHTML}>
    </div>
    ''';

  String get _alignmentStyleHTML {
    if (alignment == ReceiptAlignment.left) {
      return CollectionStyle.textLeft;
    } else if (alignment == ReceiptAlignment.right) {
      return CollectionStyle.textRight;
    }
    return CollectionStyle.textCenter;
  }

  String get _column {
    if (column == ReceiptColumn.two) {
      return CollectionStyle.columnTwo;
    } else if (column == ReceiptColumn.three) {
      return CollectionStyle.columnThree;
    }
    return CollectionStyle.columnOne;
  }
  String get _columnMargin {
    if(isMargin)
      return CollectionStyle.columnTwoMargin;
    return '';
  }

  String get _symbol {
     if(symbol!='')
       return '<sup>$symbol</sup>';
     return '';
  }
}
